@@ -421,6 +421,19 @@ static void print_rsn(const uint8_t type, uint8_t len, const uint8_t *data)
 	print_rsn_ie("CCMP", "IEEE 802.1X", len, data);
 }
 
+static void print_ht_capa(const uint8_t type, uint8_t len, const uint8_t *data)
+{
+	if (len != 26) {
+		printf("\n\t\tHT Capability IE len != expected 26 bytes, skipping parse\n");
+		return;
+	}
+	printf("\n");
+	print_ht_capability(data[0] | (data[1] << 8));
+	print_ampdu_length(data[2] & 3);
+	print_ampdu_spacing((data[2] >> 2) & 3);
+	print_ht_mcs(data + 3);
+}
+
 static void print_capabilities(const uint8_t type, uint8_t len, const uint8_t *data)
 {
 	int i, base, bit;
@@ -518,6 +531,7 @@ static const struct ie_print ieprinters[] = {
 	[7] = { "Country", print_country, 3, 255, BIT(PRINT_SCAN), },
 	[32] = { "Power constraint", print_powerconstraint, 1, 1, BIT(PRINT_SCAN), },
 	[42] = { "ERP", print_erp, 1, 255, BIT(PRINT_SCAN), },
+	[45] = { "HT capabilities", print_ht_capa, 1, 255, BIT(PRINT_SCAN), },
 	[48] = { "RSN", print_rsn, 2, 255, BIT(PRINT_SCAN), },
 	[50] = { "Extended supported rates", print_supprates, 0, 255, BIT(PRINT_SCAN), },
 	[127] = { "Extended capabilities", print_capabilities, 0, 255, BIT(PRINT_SCAN), },
@@ -541,17 +555,17 @@ static bool print_wifi_wmm_param(const uint8_t *data, uint8_t len)
 		return false;
 	}
 
-	printf("\t* Parameter version 1");
+	printf("\t * Parameter version 1");
 
 	data++;
 
 	if (data[0] & 0x80)
-		printf("\n\t\t* u-APSD");
+		printf("\n\t\t * u-APSD");
 
 	data += 2;
 
 	for (i = 0; i < 4; i++) {
-		printf("\n\t\t* %s:", aci_tbl[(data[0] >> 5) & 3]);
+		printf("\n\t\t * %s:", aci_tbl[(data[0] >> 5) & 3]);
 		if (data[4] & 0x10)
 			printf(" acm");
 		printf(" CW %d-%d", (1 << (data[1] & 0xf)) - 1,
